
var webui_i18n = {
    "BAD REQUEST": "طلب غير صحيح",
    "UNAUTHORIZED": "غير مصرح",
    "FORBIDDEN": "ممنوع",
    "NOT FOUND": "غير موجود",
    "METHOD NOT ALLOWED": "الطريقة غير مسموحة",
    "TOO MANY REQUESTS": "طلبات كثيرة جدا",
    "INTERNAL SERVER ERROR": "خطأ في الخادم الداخلي",
    "NOT IMPLEMENTED": "لم تنفذ",
    "BAD GATEWAY": "مدخل خاطأ",
    "SERVICE UNAVAILABLE": "الخدمة غير متوفرة",
    "GATEWAY TIMEOUT": "نفذ وقت الطلب",

    "request cancelled": "تم إلغاء الطلب",
    "no connection": "لا يوجد اتصال",
    "request failed": "لقد فشل الطلب",
    "Failed to load all page contents !!": "فشل تحميل كافة محتويات الصفحة !!",
    "Please reload page and try again.": "يرجى إعادة تحميل الصفحة والمحاولة مرة أخرى.",
};
